@@ -1,14 +1,15 @@
+# Copyright (c) OpenMMLab. All rights reserved.
 from mmdet.datasets.builder import PIPELINES
 
-from .formatting import (ConcatVideoReferences, SeqDefaultFormatBundle, ToList,
-                         VideoCollect)
+from .formatting import (ConcatVideoReferences, ReIDFormatBundle,
+                         SeqDefaultFormatBundle, ToList, VideoCollect)
 from .loading import (LoadDetections, LoadMultiImagesFromFile,
                       SeqLoadAnnotations)
 from .processing import MatchInstances
 from .transforms import (SeqBlurAug, SeqColorAug, SeqCropLikeSiamFC,
-                         SeqNormalize, SeqPad, SeqPhotoMetricDistortion,
-                         SeqRandomCrop, SeqRandomFlip, SeqResize,
-                         SeqShiftScaleAug)
+                         SeqGrayAug, SeqNormalize, SeqPad,
+                         SeqPhotoMetricDistortion, SeqRandomCrop,
+                         SeqRandomFlip, SeqResize, SeqShiftScaleAug)
 
 __all__ = [
     'PIPELINES', 'LoadMultiImagesFromFile', 'SeqLoadAnnotations', 'SeqResize',
@@ -16,5 +17,5 @@ __all__ = [
     'VideoCollect', 'ConcatVideoReferences', 'LoadDetections',
     'MatchInstances', 'SeqRandomCrop', 'SeqPhotoMetricDistortion',
     'SeqCropLikeSiamFC', 'SeqShiftScaleAug', 'SeqBlurAug', 'SeqColorAug',
-    'ToList'
+    'ToList', 'ReIDFormatBundle', 'SeqGrayAug'
 ]
