@@ -1,3 +1,4 @@
+# Copyright (c) OpenMMLab. All rights reserved.
 import cv2
 import mmcv
 import numpy as np
@@ -133,6 +134,43 @@ class SeqCropLikeSiamFC(object):
         return outs
 
 
+@PIPELINES.register_module()
+class SeqGrayAug(object):
+    """Gray augmention for images.
+
+    Args:
+        prob (list[float]): The probability to perform gray augmention for
+            each image. Defaults to 0..
+    """
+
+    def __init__(self, prob=0.):
+        self.prob = prob
+
+    def __call__(self, results):
+        """Call function.
+
+        For each dict in results, perform gray augmention for image in the
+        dict.
+
+        Args:
+            results (list[dict]): List of dict that from
+                :obj:`mmtrack.CocoVideoDataset`.
+
+        Returns:
+            list[dict]: List of dict that contains augmented gray image.
+        """
+        outs = []
+        gray_prob = np.random.random()
+        for _results in results:
+            if self.prob > gray_prob:
+                grayed = cv2.cvtColor(_results['img'], cv2.COLOR_BGR2GRAY)
+                image = cv2.cvtColor(grayed, cv2.COLOR_GRAY2BGR)
+                _results['img'] = image
+
+            outs.append(_results)
+        return outs
+
+
 @PIPELINES.register_module()
 class SeqShiftScaleAug(object):
     """Shift and rescale images and bounding boxes.
@@ -167,7 +205,7 @@ class SeqShiftScaleAug(object):
 
         Returns:
             tuple(crop_img, bbox): crop_img is a ndarray of shape
-            (target_size, target_size, 3), bbox is the corrsponding ground
+            (target_size, target_size, 3), bbox is the corresponding ground
             truth box in [x1, y1, x2, y2] format.
         """
         img_h, img_w = image.shape[:2]
@@ -327,7 +365,7 @@ class SeqBlurAug(object):
 class SeqResize(Resize):
     """Resize images.
 
-    Please refer to `mmdet.datasets.pipelines.transfroms.py:Resize` for
+    Please refer to `mmdet.datasets.pipelines.transforms.py:Resize` for
     detailed docstring.
 
     Args:
@@ -369,7 +407,7 @@ class SeqResize(Resize):
 class SeqNormalize(Normalize):
     """Normalize images.
 
-    Please refer to `mmdet.datasets.pipelines.transfroms.py:Normalize` for
+    Please refer to `mmdet.datasets.pipelines.transforms.py:Normalize` for
     detailed docstring.
     """
 
@@ -401,7 +439,7 @@ class SeqNormalize(Normalize):
 class SeqRandomFlip(RandomFlip):
     """Randomly flip for images.
 
-    Please refer to `mmdet.datasets.pipelines.transfroms.py:RandomFlip` for
+    Please refer to `mmdet.datasets.pipelines.transforms.py:RandomFlip` for
     detailed docstring.
 
     Args:
@@ -463,7 +501,7 @@ class SeqRandomFlip(RandomFlip):
 class SeqPad(Pad):
     """Pad images.
 
-    Please refer to `mmdet.datasets.pipelines.transfroms.py:Pad` for detailed
+    Please refer to `mmdet.datasets.pipelines.transforms.py:Pad` for detailed
     docstring.
     """
 
